#### View Menu

Image Size:
This menu controls the scaling or size of the image displayed in the scrollable panel on the right side of the main application window content area. The submenu includes the selections: 'Fit Frame', 'Original', 'Larger', Smaller', and 'to Dialog'. These are fairly self explanatory. 'Original' displays the image in its original pixel dimensions in the scroll area, meaning if it is a screen shot, it will be the size of the screen it was taken of. 'Smaller' and 'Larger' change the size by 10% per click, and 'to Dialog' opens the text cropping dialog for the image showing it in its original dimensions.
ToolBars:
This menu selection has a sub menu of check boxes which control whether either of the two tool bars are visible. There are by default two toolbars visible when the application starts, one with only icons and one with only text buttons. Each has a somewhat different set of features. but all buttons have clear help text in their tool tips and the help displayed in the status bar at the bottom. Either tool bar can be moved to any border of the main window and can be stacked with the other there. Using the check boxes in the ToolBars sub menu, you can also control which is visible at any time.